import React from 'react'
import { TouchableOpacity, View, StyleSheet, Image} from 'react-native'
import { LinearGradient }          from 'expo'
import { Feather }                 from '@expo/vector-icons'
import { Images, Metrics, Colors } from '../Themes'

/* Circle Buttons for use throughout the app */
export default class CircleButton extends React.Component {
  render() {
    return (
        <TouchableOpacity style={this.props.style} onPress={this.props.onPress}>
          <LinearGradient
            colors={[Colors.darkGradient, Colors.midGradient, Colors.lightGradient]}
            style={styles.button}
            start={[0, 1]}
            end={[1, 0]}
            locations={[0, 0.5, 1.3]}
          >
            {/* Uses an icon */}
            {this.props.icon &&
              <Feather
                name={this.props.icon}
                size={Metrics.icons.medium}
                color={Colors.snow}
              />
            }
            {/* Uses an image */}
            {this.props.source &&
              <Image
                source={this.props.source}
                style={{width: Metrics.images.medium}}
                resizeMode='contain'
              />
            }
          </LinearGradient>
        </TouchableOpacity>
    );
  }
}

const styles = StyleSheet.create({
  button: {
    justifyContent: 'center',
    alignItems: 'center',
    aspectRatio: 1,
    width: Metrics.buttons.circle,
    borderRadius: Metrics.buttons.circle/2,
    backgroundColor: Colors.lightGradient,
  },
});
