import React, { Component } from "react";
import { Alert, StyleSheet, View, PanResponder, Animated, SafeAreaView, Text } from "react-native";
import { Colors, Images, Metrics } from '../Themes'
import { connect }                           from 'react-redux'
import { bindActionCreators }                from 'redux'
import { changeFormation }                       from '../Reducers/ProjectActions'

class Flag extends Component {
  state = {
    pan: new Animated.ValueXY(),
  };
  constructor(props) {
    super(props);
    this._val = {x:0, y:0}
    this.state.pan.addListener((value) => this._val = value);

    this.panResponder = PanResponder.create({
      onStartShouldSetPanResponder: (e, gesture) => true,
      onPanResponderGrant: (e,gesture) => {
        this.state.pan.setOffset({
          x: this._val.x,
          y: this._val.y,
        })
        this.state.pan.setValue({x:0, y:0})
      },
      onPanResponderMove: Animated.event([
        null, { dx: this.state.pan.x }
      ]),
      onPanResponderRelease: (e, gesture) => {
        if (this.isDropArea(gesture)) {
          this.props._toggleModal();
          console.log('done');
        }
      }
    })
  }

  isDropArea(gesture) {
    return (64 < gesture.moveX) && (gesture.moveX < 200);
  }

  staticView = () => {
    return(
      <View style={styles.transitionLength}/>
    );
  }

  movableView = (panStyle) => {
    return(
      <Animated.View
        {...this.panResponder.panHandlers}
        style={[panStyle, styles.transitionLength]}
      />
    );
  }

  renderFlagBundle = (panStyle) => {
    return (
      <View style={{ flexDirection: 'row'}}>
        {this.renderTransitionFlag(panStyle)}
        {(this.props.movable) === true && this.movableView(panStyle)}
        {(this.props.movable) !== true && this.staticView()}
        {this.renderFormationFlag(panStyle)}
      </View>
    );
  }

  renderStem = (panStyle) => {
    return (
      <Animated.View
        {...this.panResponder.panHandlers}
        style={[panStyle, styles.flag]}
      />
    );
  }

  staticTransitionFlag = () => {
    return(
      <View style={{ justifyContent: 'center', alignItems: 'center'}}>
        <View style={styles.transitionDot}>
        </View>
        <View style={styles.flag}/>
      </View>
    );
  }

  movableTransitionFlag = (panStyle) => {
    return (
      <View style={{alignItems:'center'}}>
        <Animated.View
          {...this.panResponder.panHandlers}
          style={[panStyle, styles.transitionDot]}
        />
        {this.renderStem(panStyle)}
      </View>
    );
  }

  renderTransitionFlag = (panStyle) => {
    return (
      <View>
      {(this.props.movable === true) ? this.movableTransitionFlag(panStyle) : this.staticTransitionFlag()}
      </View>
    );
  }

  staticFormationFlag = () => {
    return(
      <View style={{ justifyContent: 'center', alignItems: 'center'}}>
        <View style={styles.formationDot}>
          <Text style={{ fontSize: 10 }}>{this.props.num}</Text>
        </View>
        <View style={styles.flag}/>
      </View>
    );
  }

  movableFormationFlag = (panStyle) => {
    return(
      <View style={{ justifyContent: 'center', alignItems: 'center'}}>
        <Animated.View
          {...this.panResponder.panHandlers}
          style={[panStyle, styles.formationDot]}
        >
          <Text style={{ fontSize: 10 }}>{this.props.num}</Text>
        </Animated.View>
        {this.renderStem(panStyle)}
      </View>
    );
  }

  renderFormationFlag = (panStyle) => {
    return (
      <View>
      {(this.props.movable === true) ? this.movableFormationFlag(panStyle) : this.staticFormationFlag()}
      </View>
    );
  }

  render() {
    const panStyle = {
      transform: this.state.pan.getTranslateTransform()
    }
    return (
      <View style={this.props.style}>
        {(this.props.transition === true) ? this.renderFlagBundle(panStyle) : this.renderFormationFlag(panStyle)}
      </View>
    );
  }

}

const styles = StyleSheet.create({
  flag: {
    backgroundColor: Colors.snow,
    width: 1,
    height: 17,
  },
  formationDot: {
    justifyContent: 'center',
    alignItems: 'center',
    position: 'absolute',
    bottom: 17,
    aspectRatio: 1,
    height: Metrics.icons.tiny,
    backgroundColor: Colors.lightGradient,
    borderRadius: Metrics.icons.small/2,
  },
  transitionDot: {
    position: 'absolute',
    bottom: 17,
    aspectRatio: 1,
    height: 13,
    backgroundColor: Colors.darkGradient,
    borderRadius: 13/2,
    borderWidth: 1,
    borderColor: Colors.snow,
  },
  transitionLength: {
    width: Metrics.section,
    backgroundColor: Colors.darkGradient,
  }
});

const mapStateToProps = (state) => {
  const { projects } = state
  return { projects }
};

const mapDispatchToProps = dispatch => (
  bindActionCreators({
    changeFormation,
  }, dispatch)
);

export default connect(mapStateToProps, mapDispatchToProps)(Flag);
