import React    from 'react'
import { StyleSheet, TouchableOpacity, View } from 'react-native'
import { Colors, Images, Metrics }            from '../Themes'
import { Feather }                         from '@expo/vector-icons'

export default class FormationCard extends React.Component {
  emptyFormation = (index) => {
    return (
      <View style={styles.emptyFormation}>
        <Feather name='plus' size={Metrics.icons.medium} color={Colors.lightGray} onPress={() => this.props.navigation.navigate('Create', {
          formations: this.state.formations[index],
          formationNum: index + 1,
        })}/>
      </View>
    );
  }
  formationThree = () => {
    return (
      <View style={{flex: 1, justifyContent:'center', ...styles.card}}>
        <View style={{flexDirection:'row', justifyContent:'center'}}>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
        </View>
        <View style={{flexDirection:'row', justifyContent:'center'}}>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
        </View>
      </View>
    );
  }

  /* Hard-coded 2nd formation: 3 Back, 2 Front */
  formationTwo = () => {
    return (
      <View style={{flex: 1, justifyContent:'center', ...styles.card}}>
        <View style={{flexDirection:'row', justifyContent:'center'}}>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
        </View>
        <View style={{flexDirection:'row', justifyContent:'center'}}>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
        </View>
      </View>
    );
  }

  /* Hard-coded 1st formation, line of 5 */
  formationOne = () => {
    return (
      <View style={{flex: 1, justifyContent:'center', ...styles.card}}>
        <View style={{flexDirection:'row', justifyContent:'center'}}>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
          <View style={styles.dot}/>
        </View>
      </View>
    );
  }

  render() {
    return (
      <View style={styles.container}>
        <TouchableOpacity onPress={() => this.props.onPress()}>
        {(this.props.index === 0) && this.formationOne()}
        {(this.props.index === 1) && this.formationTwo()}
        {(this.props.index === 2) && this.emptyFormation()}
        {(this.props.index === 3) && this.formationThree()}
        </TouchableOpacity>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    alignItems: 'center',
  },
  card: {
    backgroundColor: Colors.accent,
    flex: 3,
    aspectRatio: 1,
    borderWidth: 1,
    borderColor: Colors.lightGradient,
    borderRadius: 4,
  },
  dot: {
    aspectRatio: 1,
    height: Metrics.icons.small,
    backgroundColor: Colors.lightGradient,
    borderRadius: Metrics.icons.small/2,
    margin: 10,
  },
  emptyFormation: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    aspectRatio: 1,
    backgroundColor: Colors.accent,
    borderWidth: 2,
    borderRadius: 4,
    borderStyle: 'dashed',
    borderColor: Colors.lightGradient,
  },
});
