import React from 'react'
import { Animated, Image, PanResponder, StatusBar, StyleSheet, Text, View } from 'react-native'
import { Audio }                   from 'expo'
import { FontAwesome }             from '@expo/vector-icons'
import { Colors, Images, Metrics } from '../Themes'
import { Flag }                    from '.'

export default class PlayBar extends React.Component {
  constructor() {
    super();
    this.state = {
      paused: true,
      totalLength: 1,
      currentPosition: 0,
      selectedTrack: 0,
      repeatOn: false,
      shuffleOn: false,
      pan: new Animated.ValueXY(),
      music: new Audio.Sound(),
      isPlaying: false,
    };
  }

  componentWillMount = async () => {
    this.panResponder = PanResponder.create({
      onMoveShouldSetPanResponderCapture: () => true,

      onPanResponderGrant: (e, gesture) => {
        this.state.pan.setOffset({x: this.state.pan.x._value, y: this.state.pan.y._value});
      },

      onPanResponderMove: (event, gesture) => {
        this.state.pan.setValue({ x: gesture.dx, y: gesture.dy });
      },

      //Reduces jumpiness of cursor
      onPanResponderRelease: (e, gesture) => {
        this.state.pan.flattenOffset();
      }
    });
    await this.state.music.loadAsync(require('../../assets/fractures.mp3'));
  };

  onPress = async () => {
    if (!this.state.isPlaying) {
      try {
        await this.state.music.playAsync();
        this.setState({ isPlaying: true });
      } catch (error) {
        console.log('Error playing music');
      }
    }
    else {
      try {
        await this.state.music.pauseAsync();
        this.setState({ isPlaying: false });
      } catch (error) {
        console.log('Error playing music');
      }
    }
  }

  render() {
    icon = (this.state.isPlaying) ? 'pause' : 'play';

    const panStyle = {
      transform: this.state.pan.getTranslateTransform()
    }

    return (
      <View style={{...this.props.style, ...styles.container}}>
          <View style={styles.buttonContainer}>
            <FontAwesome name={icon} style={{color: Colors.lightGradient}} size={26} onPress={() => this.onPress()}/>
          </View>
          <View style={styles.progressBar}>
            {/* TODO: Bound the dx */}
            <Animated.View
              style={[{left: this.state.pan.x}, styles.cursor]}
              {...this.panResponder.panHandlers}
            />
            <Flag num={1}/>
            <View style={{width: Metrics.screenWidth*0.3, backgroundColor:Colors.lightGradient}}/>
            <Flag num={2} style={{marginRight: Metrics.screenWidth*0.3}}transition={true}/>
            <Flag num={3} transition={true} movable={true} _toggleModal={this.props._toggleModal}/>
          </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  buttonContainer: {
    margin: Metrics.baseMargin,
    justifyContent: 'center',
    alignItems: 'center',
    width: 26
  },
  progressBar: {
    flex: 1,
    flexDirection: 'row',
    width: undefined,
    height: 17,
    borderRadius: 7.5,
    backgroundColor: Colors.gray,
    marginRight: Metrics.doubleBaseMargin,
  },
  cursor: {
    aspectRatio: 1,
    width: 17,
    borderRadius: 17/2,
    backgroundColor: Colors.darkGradient,
    borderWidth: 1,
    borderColor: Colors.snow,
  },
  audioElement: {
    height: 0,
    width: 0,
  },
  flag: {
    width: 1,
    backgroundColor: Colors.snow,
  }
});
