import React from 'react'
import {
  Alert,
  Image,
  ImageBackground,
  Platform,
  SafeAreaView,
  StatusBar,
  StyleSheet,
  Text,
  TouchableOpacity,
  View
} from 'react-native';
import { AntDesign, MaterialCommunityIcons } from '@expo/vector-icons'
import { Dancer, SmallButton, Stage }        from '../Components'
import { Colors, Images, Metrics }           from '../Themes'
import { connect }                           from 'react-redux'
import { bindActionCreators }                from 'redux'
import { saveProject }                       from '../Reducers/ProjectActions'

/**
 * Formation creation screen
 */
class Create extends React.Component {
  constructor(props) {
    super(props);

    this.state = {
      showTrash: false,
      formations: this.props.navigation.getParam('formations'),
    }
  }
  static navigationOptions = {
    header: null,
  }

  componentDidMount() {
    Expo.ScreenOrientation.allowAsync(Expo.ScreenOrientation.Orientation.LANDSCAPE);
    StatusBar.setHidden(true);
  }

  componentWillUnmount() {
    //StatusBar.setHidden(false);
  }

  changeTrash (status){
    if (status) {
      this.setState({showTrash: true});
    }
    else {
      this.setState({showTrash: false});
    }
  }

  showAlert() {
   /* Alert.alert(
        'Alert Title',
        'Alert message here...',
        [
          {text: 'NO'},
          {text: 'Yes'}
        ]
             /*,
        '',
        [{text: 'OK'}],
        {cancelable: true}*/
    //);
  }


  renderTrash = (status) => {
    if (status) {
      return (<MaterialCommunityIcons name = "delete-forever" color = "white" size = {45} style = {{marginLeft: 9}}/>);
    }
    else return (<View/>)
  }

  onPress = () => {
    this.props.saveProject();
    this.props.navigation.navigate('Overview');
  }

  render() {
    return (
      <SafeAreaView style = {styles.container}>
        <ImageBackground style={styles.grid} source={require('../Images/grid.png')}>
          <View style = {styles.topBar}>
            <Text
              style = {{color: 'white', fontSize: 19, fontWeight: 'bold', marginLeft: 15}}>
              Formation {this.props.navigation.getParam('formationNum')}
            </Text>
            <Text style = {{color: 'white', fontSize: 19.5, paddingRight: 80}}>
              AUDIENCE
            </Text>
          <TouchableOpacity onPress={() => this.props.navigation.navigate('Overview')} style={styles.smallImageWrapper}>
            <AntDesign name = "shrink" color = "white" size = {30}/>
          </TouchableOpacity>
          </View>
          <Stage change={this.changeTrash.bind(this)} formations={this.state.formations}>
          </Stage>
          <View style = {styles.bottomBar}>
            {this.renderTrash(this.state.showTrash)}
            <SmallButton
              text='SAVE'
              onPress={this.onPress}
            />
            {/*<TouchableOpacity style = {styles.bottomButton}>
              <Text
                style = {{color: 'white', fontSize: 18}}>
                FINISH
              </Text>
            </TouchableOpacity> */}
          </View>
        </ImageBackground>
      </SafeAreaView>
    );
  }
}

//
const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  smallImageWrapper: {
    alignItems: 'center',
    justifyContent: 'center',
    marginRight: 20
  },
  grid: {
    flex: 1,
    alignSelf: 'stretch',
    width: '100%',
    //backgroundColor: 'blue',
    //height: undefined,
    alignItems: 'center',
    justifyContent: 'center',
    flexDirection: 'column'
  },
  topBar: {
    height: Platform.OS === 'ios' ? 44 : 56,
    width: '100%',
    //backgroundColor: 'black',
    marginTop: 10,
    marginLeft: 50,
    marginRight: 50,
    //flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'flex-start'
  },
  bottomBar: {
    //flex: 2.5,
    width: '100%',
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    marginBottom: Metrics.baseMargin,
    marginRight: Metrics.baseMargin,
  },
  bottomButton: {
    marginLeft: 5,
    backgroundColor: 'purple',
    justifyContent: 'center',
    alignItems: 'center',
    width: 100,
    height: 50,
    borderRadius: 75
  }
});

const mapStateToProps = (state) => {
  const { projects } = state
  return { projects }
};

const mapDispatchToProps = dispatch => (
  bindActionCreators({
    saveProject,
  }, dispatch)
);

export default connect(mapStateToProps, mapDispatchToProps)(Create);
