import React from 'react'
import { StyleSheet, Text, View, TouchableOpacity, FlatList } from 'react-native'
import { connect }                           from 'react-redux'
import { bindActionCreators }                from 'redux'
import { addProject }                        from '../Reducers/ProjectActions'
import { Feather }                           from '@expo/vector-icons'
import { DanceCard, LargeButton, SongCard }  from '../Components'
import { Colors, Metrics }                   from '../Themes'

/**
 * Home screen of the App
 * -----------------------------------
 * - View recent and previous projects
 * - Create new projects
 */
class Home extends React.Component {
  /* Navigation options */
  static navigationOptions = {
    title: 'DANCES',
    headerTitleStyle: {
      color: Colors.snow,
      fontWeight: 'normal',
    },
    headerStyle: {
      backgroundColor: Colors.accent,
      borderBottomWidth: 0,
    },
    headerRight:
      <TouchableOpacity>
        <Feather name='search' size={Metrics.icons.medium} color={Colors.snow}/>
      </TouchableOpacity>,
    headerRightContainerStyle: {
      marginRight: Metrics.doubleBaseMargin,
    },
  }

  /* Add separation between DanceCards */
  danceCardSeparator = () => {
    return (
      <View style={{ width:Metrics.baseMargin, backgroundColor:Colors.background }}/>
    );
  }

  /* Return a DanceCard Component */
  renderDanceCard = ({item, index}) => {
    return (
      <View style={{flexDirection: 'row'}}>
        {(index === 0) && this.danceCardSeparator()}
        <DanceCard
          name={item.name}
          numDancers={item.numDancers}
          onPress={() => this.props.navigation.navigate('Overview')}
        />
        {(index === (this.props.projects.recent.length - 1)) && this.danceCardSeparator()}
      </View>
    )
  }

  /* Add separation between SongCards */
  songCardSeparator = () => {
    return (
      <View style={{ height: 1, backgroundColor: Colors.background }}/>
    );
  }

  /* Return a SongCard Component */
  renderSongCard = ({item}) => {
    return (
      <SongCard
        name={item.name}
        onPress={() => this.props.navigation.navigate('Overview')}
      />
    );
  }

  componentWillMount() {
    Expo.ScreenOrientation.allowAsync(Expo.ScreenOrientation.Orientation.PORTRAIT);
  }

  render() {
    return (
      <View style={styles.container}>
        {/*Recent projects*/}
        <View style={styles.recent}>
          <Text style={styles.title}>RECENT</Text>
          <FlatList
            data={this.props.projects.recent}
            renderItem={this.renderDanceCard}
            keyExtractor={(item, index) => index.toString()}
            horizontal={true}
            ItemSeparatorComponent={this.danceCardSeparator}
          />
        </View>

        {/*All projects*/}
        <View style={styles.all}>
          <Text style={styles.title}>ALL</Text>
          <View style={styles.songCards}>
            <FlatList
              data={this.props.projects.all}
              renderItem={this.renderSongCard}
              keyExtractor={(item, index) => index.toString()}
              ItemSeparatorComponent={this.songCardSeparator}
            />
            <LargeButton
              style={styles.createButton}
              text='CREATE'
              onPress={() => this.props.navigation.navigate('NameProj')}
            />
          </View>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: Colors.background,
  },
  recent: {
    flex: 2,
  },
  all: {
    flex: 3,
  },
  songCards: {
    flex: 4,
  },
  title: {
    marginTop: Metrics.doubleBaseMargin,
    marginBottom: Metrics.doubleBaseMargin,
    marginLeft: Metrics.doubleSection,
    fontSize: Metrics.text.bold,
    color: Colors.snow,
  },
  createButton: {
    flex: 1,
    alignSelf: 'center',
    position: 'absolute',
    bottom: Metrics.baseMargin,
    marginBottom: Metrics.doubleBaseMargin,
  },
});

const mapStateToProps = (state) => {
  const { projects } = state
  return { projects }
};

const mapDispatchToProps = dispatch => (
  bindActionCreators({
    addProject,
  }, dispatch)
);

export default connect(mapStateToProps, mapDispatchToProps)(Home);
