import React from 'react'
import { TouchableOpacity, View, StyleSheet, Text, TextInput} from 'react-native'
import { connect }                 from 'react-redux'
import { bindActionCreators }      from 'redux'
import { nameProject }             from '../Reducers/ProjectActions'
import { Feather }                 from '@expo/vector-icons'
import { CircleButton }            from '../Components'
import { Colors, Images, Metrics } from '../Themes'

/**
 * 1st PreCreate Screen. Names the new project.
 */
class NameProj extends React.Component {
  static navigationOptions = {
    header: null,
  }

  state = {
    name: ''
  }

  render() {
    return (
      <View style={styles.container}>
        <Text style={styles.text}>NAME YOUR PROJECT</Text>
        <TextInput
          style={styles.textInput}
          onChangeText={(name) => {this.setState({ name: name })}}
          value={this.state.name}
        />
        <View style={styles.buttonContainer}>
          <CircleButton icon='arrow-left'
            onPress={() => this.props.navigation.navigate('Home')}/>
          <CircleButton icon='arrow-right'
            onPress={() => this.props.navigation.navigate('UploadSong')}/>
        </View>
      </View>
    );
  }
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: Colors.background,
  },
  text: {
    fontSize: Metrics.text.button,
    margin: Metrics.baseMargin,
    color: Colors.snow,
    position: 'absolute',
    top: Metrics.screenHeight*0.4,
  },
  textInput: {
    width: 251,
    height: 46,
    fontSize: Metrics.text.normal,
    borderRadius: 23,
    color: Colors.snow,
    backgroundColor: Colors.accent,
    paddingLeft: Metrics.doubleBaseMargin,
  },
  buttonContainer: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'space-between',
    position: 'absolute',
    bottom: Metrics.screenHeight * 0.05,
    width: Metrics.screenWidth,
    paddingHorizontal: Metrics.doubleBaseMargin * 2,
  },
});

const mapStateToProps = (state) => {
  const { projects } = state
  return { projects }
};

const mapDispatchToProps = dispatch => (
  bindActionCreators({
    nameProject,
  }, dispatch)
);

export default connect(mapStateToProps, mapDispatchToProps)(NameProj);
